@@ -6,7 +6,7 @@ class BartApi():
     self.api_key = api_key
 
   def parse_response(self,raw_xml):
-    parsed_xml = etree.fromstring(raw_xml, parser=etree.XMLParser(encoding='utf-8'))
+    parsed_xml = etree.parse(raw_xml)
     return parsed_xml
 
   def number_of_trains(self):
